diff --git a/scripts/Debian/DictionariesCommon.pm.in b/scripts/Debian/DictionariesCommon.pm.in
index 7fd7feb..3d9a4b6 100644
--- a/scripts/Debian/DictionariesCommon.pm.in
+++ b/scripts/Debian/DictionariesCommon.pm.in
@@ -438,20 +438,33 @@ sub build_squirrelmail_support {
 # Build support file for squirrelmail with a list of available
 # dictionaries and associated spellchecker calls, in php format.
 # ------------------------------------------------------------------
-  my $class        = "ispell";
-  my $dictionaries = loaddb ($class);
+  my @classes      = ("aspell","ispell");
   my $php          = "<?php\n";
   my @dictlist     = ();
 
   $php .= generate_comment ("### ");
   $php .= "\$SQSPELL_APP = array (\n";
-  foreach ( keys %$dictionaries ){
-    next if m/.*[^a-z]tex[^a-z]/i;            # Discard tex variants
-    my $spellchecker_params =
-	&dc_get_spellchecker_params($class,$dictionaries->{$_});
-    push @dictlist, qq {  '$_' => 'ispell -a $spellchecker_params'};
+
+  foreach my $class (@classes) {
+    my $dictionaries = loaddb ($class);
+    foreach ( keys %$dictionaries ){
+      next if m/.*[^a-z]tex[^a-z]/i;            # Discard tex variants
+      my $lang = $dictionaries->{$_};
+      my $squirrelname;
+      if ( defined $lang->{"squirrelmail"} ){
+	next if ( lc($lang->{"squirrelmail"}) eq "no" );
+	$squirrelname = $lang->{"squirrelmail"};
+      } else {
+	next unless m/^(\S+)\s+\((.+)\)$/;
+	$squirrelname = $2;
+      }
+      my $spellchecker_params =
+	&dc_get_spellchecker_params($class,$lang);
+      push @dictlist, qq {  '$squirrelname ($class)' => '$class -a $spellchecker_params'};
+    }
   }
-  $php .= join(",\n", @dictlist);
+
+  $php .= join(",\n", sort @dictlist);
   $php .= "\n);\n";
 
   open (PHP, "> $cachedir/$squirrelmailsupport")
diff --git a/scripts/system/update-dictcommon.in b/scripts/system/update-dictcommon.in
index 998e3ae..a029e03 100644
--- a/scripts/system/update-dictcommon.in
+++ b/scripts/system/update-dictcommon.in
@@ -11,6 +11,7 @@ my %locales    = ();
 updatedb ($class);
 build_emacsen_support ();
 build_jed_support ();
+build_squirrelmail_support ();
 
 system ("aspell-autobuildhash") == 0
     or die "Error running aspell-autobuildhash\n";
